package com.chokwapeem.game;

import org.usb4java.Device;

public class McuWithPeriBoard extends McuBoard
{
	private static final byte RQ_SET_LED       = 0;
    private static final byte RQ_SET_LED_VALUE = 1;
    private static final byte RQ_GET_SWITCH    = 2;
    private static final byte RQ_GET_X_AXIS    = 3;
    private static final byte RQ_GET_Y_AXIS	   = 4;
    private static final byte RQ_GET_LED1	   = 5;
    private static final byte RQ_GET_LED2	   = 6;
    private static final byte RQ_GET_LED3	   = 7;
    
    public McuWithPeriBoard(Device device) {
		super(device);
	}

    /**
     * Set status of LED on peripheral board
     *
     * @param ledNo  the number of LED (0,1,2) to set status
     * @param value  status to set (0-off, 1-on)
     */
    public void setLed(int num, int value)
    {
        this.write(RQ_SET_LED, (short) num, (short) value);
    }

    /**
     * Display a binary value on the peripheral board's LEDs
     *
     * @param value The value to be displayed on the LEDs
     */
    public void setLedValue(int value)
    {
        this.write(RQ_SET_LED_VALUE, (short) 0, (short) (value));
    }

    /**
     * Check the state of the switch
     *
     * @return true when the switch is pressed; false otherwise
     */
    public boolean getSwitch()
    {
        byte[] ret = this.read(RQ_GET_SWITCH, (short) 0, (short) 0);
        return ret[0] == 1;
    }

    /**
     * Read and return the light intensity
     *
     * @return a value between 0-1023; the greater the intensity, the higher the value
     */
    public int getXAxis()
    {
        byte[] ret = this.read(RQ_GET_X_AXIS, (short) 0, (short) 0);
        return (ret[0] & 0xFF) + (ret[1] & 0xFF)*256;
    }
    
    public int getYAxis()
    {
        byte[] ret = this.read(RQ_GET_Y_AXIS, (short) 0, (short) 0);
        return (ret[0] & 0xFF) + (ret[1] & 0xFF)*256;
    }
    
    
}