package com.chokwapeem.game;

import java.awt.geom.Line2D;
import java.awt.geom.Point2D;
import java.util.ArrayList;

import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer.ShapeType;
import com.badlogic.gdx.math.MathUtils;

public class Player extends SpaceObject{
	
	private final int MAX_BULLETS = 3;
	private ArrayList<Bullet> bullets;
	
	private boolean left;
	private boolean right;
	private boolean up;
	private boolean down;

	private float maxSpeed;
	private float acceleration;
	private float deceleration;
	
	private boolean hit;
	private boolean dead;
	
	private float hitTime;
	private float hitTimer;
	private Line2D.Float[] hitLines;
	private Point2D.Float[] hitLinesVector;
	
	private long score;
	private int lifeCount = 2;
	
	public Player(ArrayList<Bullet> bullets) {
		
		this.bullets = bullets;
		
		x = SpaceShooter.WIDTH / 2;
		y = SpaceShooter.HEIGHT / 2;
		
		maxSpeed = 300;
		acceleration = 200;
		deceleration = 10;
		
		shapex = new float[4];
		shapey = new float[4];
		
		radians = 3.1415f / 2;
		rotationSpeed = 3;
		
		score = 0;
		
		hit = false;
		hitTimer = 0;
		hitTime = 2;
		
	}
	
	private void setShape() {
		shapex[0] = x + MathUtils.cos(radians) * 8;
		shapey[0] = y + MathUtils.sin(radians) * 8;

		shapex[1] = x + MathUtils.cos(radians - 4 * (float)Math.PI / 5) * 8;
		shapey[1] = y + MathUtils.sin(radians - 4 * (float)Math.PI  / 5) * 8;

		shapex[2] = x + MathUtils.cos(radians + (float)Math.PI ) * 5;
		shapey[2] = y + MathUtils.sin(radians + (float)Math.PI ) * 5;

		shapex[3] = x + MathUtils.cos(radians + 4 * (float)Math.PI  / 5) * 8;
		shapey[3] = y + MathUtils.sin(radians + 4 * (float)Math.PI  / 5) * 8;

	}
	
	public void setLeft(boolean b) {
		left = b;
	}

	public void setRight(boolean b) {
		right = b;
	}

	public void setUp(boolean b) {
		up = b;
	}
	
	public long getScore() {
		return score;
	}
	
	public void incrementScore(long l) {
		score += l;
	}
	
	public void shoot() {
		if(bullets.size() == MAX_BULLETS) return;
		bullets.add(new Bullet(x, y, radians));
	}
	
	public void hit() {
		if(hit) {
			return;
		}
		
		hitLines = new Line2D.Float[4];
		for(int i = 0, j = hitLines.length - 1; i < hitLines.length; j = i++) {
			hitLines[i] = new Line2D.Float(shapex[i], shapey[i], shapex[j], shapey[j]);
		}
		hitLinesVector = new Point2D.Float[4];
		hitLinesVector[0] = new Point2D.Float(MathUtils.cos(radians + 1.5f), MathUtils.sin(radians + 1.5f));
		hitLinesVector[1] = new Point2D.Float(MathUtils.cos(radians - 1.5f), MathUtils.sin(radians - 1.5f));
		hitLinesVector[2] = new Point2D.Float(MathUtils.cos(radians - 2.8f), MathUtils.sin(radians - 2.8f));
		hitLinesVector[3] = new Point2D.Float(MathUtils.cos(radians + 2.8f), MathUtils.sin(radians + 2.8f));
		
		if(lifeCount == 2) {
			SpaceShooter.peri.setLedValue(3);
			
		}
		
		if(lifeCount == 1) {
			SpaceShooter.peri.setLedValue(1);
			
		}
		
		if(lifeCount == 0) {
			SpaceShooter.peri.setLedValue(0);
			hit = true;
			dx = 0;
			dy = 0;
			left = false;
			right = false;
			up = false;
			down = false;
			
		}
		lifeCount--;
	}
	
	public void update(float dt) {
		boolean sw = SpaceShooter.peri.getSwitch();
        int xvalue = SpaceShooter.peri.getXAxis();
        int yvalue = SpaceShooter.peri.getYAxis();
        
		if(lifeCount == -1) {
			hitTimer += dt;
			if(hitTimer > hitTime) {
				dead = true;
				hitTimer = 0;
			}
			for(int i = 0; i < hitLines.length; i++) {
				hitLines[i].setLine(hitLines[i].x1 + hitLinesVector[i].x * 10 * dt, hitLines[i].y1 + hitLinesVector[i].y * 10 * dt, hitLines[i].x2 + hitLinesVector[i].x * 10 * dt, hitLines[i].y2 + hitLinesVector[i].y * 10 * dt);
			}
			
			return;
		}
		
		
        if(lifeCount == 2) {
        	SpaceShooter.peri.setLedValue(63);
        }
		if(xvalue >= 1000) {
			radians += rotationSpeed * dt;
		} else if(xvalue <= 100) {
			radians -= rotationSpeed * dt;
		}
		
		if(yvalue >= 1000) {
			dx += MathUtils.cos(radians) * acceleration * dt;
			dy += MathUtils.sin(radians) * acceleration * dt;
			
		}
		
		if(sw) {
			shoot();
			
		}
		
		float vec = (float) Math.sqrt(Math.pow(dx, 2) + Math.pow(dy, 2));
		if(vec > 0) {
			dx -= (dx / vec) * deceleration * dt;
			dy -= (dy / vec) * deceleration * dt;
		}
		if(vec > maxSpeed) {
			dx = (dx / vec) * maxSpeed;
			dy = (dy / vec) * maxSpeed;
			
			
		}
		
		x += dx * dt;
		y += dy * dt;

		setShape();
		wrap();
	}
	
	public void draw (ShapeRenderer sr) {
		sr.setColor(255, 255, 0, 1);
		sr.begin(ShapeType.Line);
		if(hit) {
			for(int i = 0; i < hitLines.length; i++) {
				sr.line(hitLines[i].x1, hitLines[i].y1, hitLines[i].x2, hitLines[i].y2);
			}
			sr.end();
			return;
			
		}
	
		for(int i = 0, j = shapex.length - 1; i < shapex.length; j = i++) {
			sr.line(shapex[i], shapey[i], shapex[j], shapey[j]);
		}
		
		sr.end();
	}

}

