#include <avr/io.h>
#include <avr/interrupt.h>  /* for sei() */
#include <util/delay.h>     /* for _delay_ms() */
#include <avr/pgmspace.h>   /* required by usbdrv.h */

#include "peri.h"
#include "usbdrv.h"

#define RQ_SET_LED         0
#define RQ_SET_LED_VALUE   1
#define RQ_GET_SWITCH      2
#define RQ_GET_X_AXIS      3
#define RQ_GET_Y_AXIS      4
#define RQ_GET_LED1        5
#define RQ_GET_LED2        6
#define RQ_GET_LED3        7
/* ------------------------------------------------------------------------- */
/* ----------------------------- USB interface ----------------------------- */
/* ------------------------------------------------------------------------- */
usbMsgLen_t usbFunctionSetup(uint8_t data[8])
{
    usbRequest_t *rq = (void *)data;

    /* declared as static so they stay valid when usbFunctionSetup returns */
    static uint8_t switch_state;

    if (rq->bRequest == RQ_SET_LED)
    {
        uint8_t led_val = rq->wValue.bytes[0];
        uint8_t led_no  = rq->wIndex.bytes[0];
        set_led(led_no, led_val);
        return 0;
    }

    else if (rq->bRequest == RQ_SET_LED_VALUE)
    {
        uint8_t led_val = rq->wValue.bytes[0];
        set_led_value(led_val);
        return 0;
    }

    else if (rq->bRequest == RQ_GET_SWITCH)
    {
        switch_state = IS_SWITCH_PRESSED();
        /* point usbMsgPtr to the data to be returned to host */
        usbMsgPtr = &switch_state;
        /* return the number of bytes of data to be returned to host */
        return sizeof(switch_state);
    }

    else if (rq->bRequest == RQ_GET_X_AXIS)
    {
        static uint16_t light;
        light = read_adc(PC0);
        usbMsgPtr = &light;

        return sizeof(light);
    }

    else if (rq->bRequest == RQ_GET_Y_AXIS)
    {
        static uint16_t light;
        light = read_adc(PC1);
        usbMsgPtr = &light;

        return sizeof(light);
    }

    // else if (rq->bRequest == RQ_GET_LED1) {
    //     set_led_value(0b001);
    //
    //     return 0;
    // }
    //
    //
    // else if (rq->bRequest == RQ_GET_LED2) {
    //     set_led_value(0b011);
    //
    //     return 0;
    // }
    //
    // else if (rq->bRequest == RQ_GET_LED3) {
    //     set_led_value(0b111);
    //
    //     return 0;
    // }
    /* default for not implemented requests: return no data back to host */
    return 0;
}

/* ------------------------------------------------------------------------- */
int main(void)
{
    init_peripheral();

    usbInit();

    /* enforce re-enumeration, do this while interrupts are disabled! */
    usbDeviceDisconnect();
    _delay_ms(300);
    usbDeviceConnect();

    /* enable global interrupts */
    sei();

    /* main event loop */
    for(;;)
    {
        usbPoll();
    }

    return 0;
}

/* ------------------------------------------------------------------------- */
